California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 47 - KINDERGARTEN-UNIVERSITY PUBLIC EDUCATION FACILITIES BOND ACT OF 2002. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
900868 | BUILDERS FOR PROP. 47 AND PROP. 46 SPONSORED BY CALIFORNIA BUILDING INDUSTRY ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1245448 | YES ON 47: TAXPAYERS, PARENTS, EDUCATORS, BUSINESS, LABOR, BUILDERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1249695 | TEMECULA VALLEY YES ON PROP 47 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1249945 | VALLEY CITIZENS FOR PROPOSITION 47 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220380 | COMMUNITY COLLEGE FACILITY COALITION ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1224009 | CALIFORNIANS FOR HIGHER EDUCATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980478 | COALITION FOR ADEQUATE SCHOOL HOUSING ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1231681 | FUND FOR BETTER SCHOOLS - YES ON 47 | SUPPORT